"""Top-level package for sgnova.

import flattening and version handling
"""

try:
    from ._version import version as __version__
except ImportError:
    __version__ = "?.?.?"

# Import flattening
from sgnova.transforms import Power



"""Unit tests for the power module
"""

from sgnova import Power


class TestPower:
    """Test group for Power transformations
    """

    def test_init(self):
        """Test create a Power transform"""
        p = Power()
        assert isinstance(p, Power)
